pub struct AnyMergeVarBuilder { /* private fields */ }Expand description
Build a merge_var! from any number of input vars of any type.
Implementations
Sourceimpl AnyMergeVarBuilder
impl AnyMergeVarBuilder
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
New with pre-allocated inputs.
Sourcepub fn build_any(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_any( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-only merge var.
Sourcepub fn build<O: VarValue>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
) -> Var<O>
pub fn build<O: VarValue>( self, merge: impl FnMut(&[AnyVar]) -> O + Send + 'static, ) -> Var<O>
Build a read-only strongly typed merge var.
Sourcepub fn build_bidi_any(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
map_back: impl FnMut(&dyn AnyVarValue, usize) -> BoxAnyVarValue + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_bidi_any( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, map_back: impl FnMut(&dyn AnyVarValue, usize) -> BoxAnyVarValue + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-write merge var.
Sourcepub fn build_bidi_any_modify(
self,
merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static,
modify_back: impl FnMut(&dyn AnyVarValue, usize, &mut AnyVarModify<'_>) + Send + 'static,
output_type: TypeId,
) -> AnyVar
pub fn build_bidi_any_modify( self, merge: impl FnMut(&[AnyVar]) -> BoxAnyVarValue + Send + 'static, modify_back: impl FnMut(&dyn AnyVarValue, usize, &mut AnyVarModify<'_>) + Send + 'static, output_type: TypeId, ) -> AnyVar
Build a read-write merge var that modifies each input back.
Sourcepub fn build_bidi<O: VarValue>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
map_back: impl FnMut(&O, usize) -> BoxAnyVarValue + Send + 'static,
) -> Var<O>
pub fn build_bidi<O: VarValue>( self, merge: impl FnMut(&[AnyVar]) -> O + Send + 'static, map_back: impl FnMut(&O, usize) -> BoxAnyVarValue + Send + 'static, ) -> Var<O>
Build a read-write strongly typed merge var.
Sourcepub fn build_bidi_modify<O: VarValue>(
self,
merge: impl FnMut(&[AnyVar]) -> O + Send + 'static,
modify_back: impl FnMut(&O, usize, &mut AnyVarModify<'_>) + Send + 'static,
) -> Var<O>
pub fn build_bidi_modify<O: VarValue>( self, merge: impl FnMut(&[AnyVar]) -> O + Send + 'static, modify_back: impl FnMut(&O, usize, &mut AnyVarModify<'_>) + Send + 'static, ) -> Var<O>
Build a read-write strongly typed merge var that modifies each input back.
Sourcepub fn into_typed<I: VarValue>(self) -> MergeVarBuilder<I>
pub fn into_typed<I: VarValue>(self) -> MergeVarBuilder<I>