pub struct VarHandle(/* private fields */);Expand description
Handle to a variable hook.
This can represent a widget subscriber, a var binding, var app handler or animation, dropping the handler stops the behavior it represents.
Implementations
sourceimpl VarHandle
impl VarHandle
sourcepub fn perm(self)
pub fn perm(self)
Drop the handle without stopping the behavior it represents.
Note that the behavior can still be stopped by dropping the involved variables.
sourcepub fn with(self, other: Self) -> VarHandles
pub fn with(self, other: Self) -> VarHandles
Create a VarHandles collection with self and other.